#!/bin/bash
#
# This script runs the mesher and solver using this example setup from the paper :
# Bottero Alexis, Cristini Paul, Komatitsch Dimitri, Asch Mark. An axisymmetric time-domain spectral-element
# method for full-wave simulations: Application to ocean acoustics. J. Acoust. Soc. Am. 140, 3520 (2016).
# http://scitation.aip.org/content/asa/journal/jasa/140/5/10.1121/1.4965964?aemail=author

echo "ice over water over land: `date`"
currentdir=`pwd`

# Sets up directory structure in current example directoy
echo
echo " Setting up the simulation..."
echo

mkdir -p OUTPUT_FILES
mkdir -p DATA


# Clean output files
rm -rf OUTPUT_FILES/* DATA/*

# Sets up local DATA/ directory
cp Par_file DATA
cp SOURCE DATA
cp STATIONS DATA

rm -f xmeshfem2D xspecfem2D
ln -s /nfs/grad/dukeleto/eric/specFEM2d/specfem2d/bin/xmeshfem2D
ln -s /nfs/grad/dukeleto/eric/specFEM2d/specfem2d/bin/xspecfem2D

# Get the number of processors
NPROC=`grep NPROC DATA/Par_file | cut -d = -f 2 | cut -d \# -f 1 | tr -d ' '`

# Run database generation
echo
echo " Running mesher..."
echo
./xmeshfem2D

if [ "$NPROC" -eq 1 ]; then # This is a serial simulation
  echo
  echo " Running solver..."
  echo
  ./xspecfem2D
else # This is a MPI simulation
  echo
  echo " Running solver on $NPROC processors..."
  echo
  mpirun -np $NPROC ./xspecfem2D
fi

# Store output
cp DATA/*SOURCE* DATA/*STATIONS* OUTPUT_FILES

echo
echo "See results in directory: OUTPUT_FILES/"
echo
echo "Done!"
date
